"""
a module consisting of one function print_lol(list)
"""
def print_lol(the_list,level=0):
    """this function prints a list which may contain lists
    as input a object that must be a list"""
    #another way to write a comment
    for each_item in the_list:
        if isinstance( each_item, list):
            print_lol( each_item,level+1 )
        else:
            for tab_stop in range(level):
                print("\t",end='')
            print(each_item)
 



from distutils.core import setup
setup(
    name = 'nesterSV',
    version = '1.2.0',
    py_modules = ['nesterSV'],
    author = 'SanderVos2401',
    author_email = 'sandervos2401@hotmail.nl',
    url = 'http://www.headfirstlabs.com',
    description = 'A simple printer of nested lists',
    )
